@@ -28,7 +28,9 @@ def _test_convert_messages(runner):
             role="user",
         )
     ]
-    actual_message = runner._convert_messages(message, session_id="test_session_id")
+    actual_message = runner._convert_messages(
+        message, session_id="test_session_id", upload_inline_data_to_tos=True
+    )
     assert actual_message == expected_message
 
     message = ["test message 1", "test message 2"]
@@ -42,7 +44,9 @@ def _test_convert_messages(runner):
             role="user",
         ),
     ]
-    actual_message = runner._convert_messages(message, session_id="test_session_id")
+    actual_message = runner._convert_messages(
+        message, session_id="test_session_id", upload_inline_data_to_tos=True
+    )
     assert actual_message == expected_message
 
 
