@@ -28,10 +28,10 @@ from typing_extensions import Any
 
 from veadk.config import getenv
 from veadk.consts import (
-    DEFAULT_MODEL_AGENT_PROVIDER,
     DEFAULT_MODEL_AGENT_API_BASE,
     DEFAULT_MODEL_AGENT_NAME,
-    DEFAULT_MODEL_EXTRA_HEADERS,
+    DEFAULT_MODEL_AGENT_PROVIDER,
+    DEFAULT_MODEL_EXTRA_CONFIG,
 )
 from veadk.evaluation import EvalSetRecorder
 from veadk.knowledgebase import KnowledgeBase
@@ -101,11 +101,23 @@ class Agent(LlmAgent):
     def model_post_init(self, __context: Any) -> None:
         super().model_post_init(None)  # for sub_agents init
 
-        # add model request source (veadk) in extra headers
-        if self.model_extra_config and "extra_headers" in self.model_extra_config:
-            self.model_extra_config["extra_headers"] |= DEFAULT_MODEL_EXTRA_HEADERS
-        else:
-            self.model_extra_config["extra_headers"] = DEFAULT_MODEL_EXTRA_HEADERS
+        # combine user model config with VeADK defaults
+        headers = DEFAULT_MODEL_EXTRA_CONFIG["extra_headers"].copy()
+        body = DEFAULT_MODEL_EXTRA_CONFIG["extra_body"].copy()
+
+        if self.model_extra_config:
+            user_headers = self.model_extra_config.get("extra_headers", {})
+            user_body = self.model_extra_config.get("extra_body", {})
+
+            headers |= user_headers
+            body |= user_body
+
+        self.model_extra_config |= {
+            "extra_headers": headers,
+            "extra_body": body,
+        }
+
+        logger.info(f"Model extra config: {self.model_extra_config}")
 
         if not self.model:
             self.model = LiteLlm(
