@@ -33,12 +33,11 @@ while [[ $# -gt 0 ]]; do
     esac
 done
 
-# in case of uvicorn and fastapi not installed in user's requirements.txt
-python3 -m pip install uvicorn[standard]
-
-python3 -m pip install fastapi
-
-python3 -m pip install fastmcp
+# Check if MODEL_AGENT_API_KEY is set
+if [ -z "$MODEL_AGENT_API_KEY" ]; then
+    echo "MODEL_AGENT_API_KEY is not set. Please set it in your environment variables."
+    exit 1
+fi
 
 USE_ADK_WEB=${USE_ADK_WEB:-False}
 
